pub struct CatalogNode {
pub id: String,
pub node: String,
pub address: String,
pub datacenter: String,
pub TaggedAddresses: Option<HashMap<String, String>>,
pub Meta: Option<HashMap<String, String>>,
}Expand description
The node information of an instance providing a Consul service.
Fields
id: StringThe ID of the service node.
node: StringThe name of the Consul node on which the service is registered
address: StringThe IP address of the Consul node on which the service is registered.
datacenter: StringThe datacenter where this node is running on.
TaggedAddresses: Option<HashMap<String, String>>Tagged addressed to register with.
Meta: Option<HashMap<String, String>>Optional key value meta associated with the service.