CreateOrUpdateKeyRequest

Struct CreateOrUpdateKeyRequest 

pub struct CreateOrUpdateKeyRequest<'a> {
    pub key: &'a str,
    pub namespace: &'a str,
    pub datacenter: &'a str,
    pub flags: u64,
    pub check_and_set: Option<i64>,
    pub acquire: &'a str,
    pub release: &'a str,
}
Represents a request to read a key from Consul Key Value store.

Fields

key: &'a str

Specifies the path of the key.

namespace: &'a str

Specifies the namespace to query. If not provided, the namespace will be inferred from the request’s ACL token, or will default to the default namespace. This is specified as part of the URL as a query parameter. Added in Consul 1.7.0.

datacenter: &'a str

Specifies the datacenter to query. This will default to the datacenter of the agent being queried.

flags: u64

Specifies an unsigned value between 0 and (2^64)-1. Clients can choose to use this however makes sense for their application.

check_and_set: Option<i64>

Specifies to use a Check-And-Set operation. This is very useful as a building block for more complex synchronization primitives. If the index is 0, Consul will only put the key if it does not already exist. If the index is non-zero, the key is only set if the index matches the ModifyIndex of that key.

acquire: &'a str

Supply a session ID to use in a lock acquisition operation. This is useful as it allows leader election to be built on top of Consul. If the lock is not held and the session is valid, this increments the LockIndex and sets the Session value of the key in addition to updating the key contents. A key does not need to exist to be acquired. If the lock is already held by the given session, then the LockIndex is not incremented but the key contents are updated. This lets the current lock holder update the key contents without having to give up the lock and reacquire it. Note that an update that does not include the acquire parameter will proceed normally even if another session has locked the key.

release: &'a str

Supply a session ID to use in a release operation. This is useful when paired with ?acquire= as it allows clients to yield a lock. This will leave the LockIndex unmodified but will clear the associated Session of the key. The key must be held by this session to be unlocked.

Implementations

Source

impl<'a> CreateOrUpdateKeyRequest<'a>

pub fn builder() -> CreateOrUpdateKeyRequestBuilder<'a>

Create an instance of CreateOrUpdateKeyRequest using the builder syntax