CreateOrUpdateKeyRequestBuilder

Struct CreateOrUpdateKeyRequestBuilder 

pub struct CreateOrUpdateKeyRequestBuilder<'a, S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<'a, S: State> CreateOrUpdateKeyRequestBuilder<'a, S>

pub fn build(self) -> CreateOrUpdateKeyRequest<'a>
where S: IsComplete,

Finish building and return the requested object

pub fn key( self, value: &'a str, ) -> CreateOrUpdateKeyRequestBuilder<'a, SetKey<S>>
where S::Key: IsUnset,

Required.

Specifies the path of the key.

pub fn namespace( self, value: &'a str, ) -> CreateOrUpdateKeyRequestBuilder<'a, SetNamespace<S>>
where S::Namespace: IsUnset,

Optional (Some / Option setters). Default: <&'a str as Default>::default().

Specifies the namespace to query. If not provided, the namespace will be inferred from the request’s ACL token, or will default to the default namespace. This is specified as part of the URL as a query parameter. Added in Consul 1.7.0.

pub fn maybe_namespace( self, value: Option<&'a str>, ) -> CreateOrUpdateKeyRequestBuilder<'a, SetNamespace<S>>
where S::Namespace: IsUnset,

Optional (Some / Option setters). Default: <&'a str as Default>::default().

Specifies the namespace to query. If not provided, the namespace will be inferred from the request’s ACL token, or will default to the default namespace. This is specified as part of the URL as a query parameter. Added in Consul 1.7.0.

pub fn datacenter( self, value: &'a str, ) -> CreateOrUpdateKeyRequestBuilder<'a, SetDatacenter<S>>
where S::Datacenter: IsUnset,

Optional (Some / Option setters). Default: <&'a str as Default>::default().

Specifies the datacenter to query. This will default to the datacenter of the agent being queried.

pub fn maybe_datacenter( self, value: Option<&'a str>, ) -> CreateOrUpdateKeyRequestBuilder<'a, SetDatacenter<S>>
where S::Datacenter: IsUnset,

Optional (Some / Option setters). Default: <&'a str as Default>::default().

Specifies the datacenter to query. This will default to the datacenter of the agent being queried.

pub fn flags( self, value: u64, ) -> CreateOrUpdateKeyRequestBuilder<'a, SetFlags<S>>
where S::Flags: IsUnset,

Optional (Some / Option setters). Default: 0.

Specifies an unsigned value between 0 and (2^64)-1. Clients can choose to use this however makes sense for their application.

pub fn maybe_flags( self, value: Option<u64>, ) -> CreateOrUpdateKeyRequestBuilder<'a, SetFlags<S>>
where S::Flags: IsUnset,

Optional (Some / Option setters). Default: 0.

Specifies an unsigned value between 0 and (2^64)-1. Clients can choose to use this however makes sense for their application.

pub fn check_and_set( self, value: i64, ) -> CreateOrUpdateKeyRequestBuilder<'a, SetCheckAndSet<S>>
where S::CheckAndSet: IsUnset,

Optional (Some / Option setters). Specifies to use a Check-And-Set operation. This is very useful as a building block for more complex synchronization primitives. If the index is 0, Consul will only put the key if it does not already exist. If the index is non-zero, the key is only set if the index matches the ModifyIndex of that key.

pub fn maybe_check_and_set( self, value: Option<i64>, ) -> CreateOrUpdateKeyRequestBuilder<'a, SetCheckAndSet<S>>
where S::CheckAndSet: IsUnset,

Optional (Some / Option setters). Specifies to use a Check-And-Set operation. This is very useful as a building block for more complex synchronization primitives. If the index is 0, Consul will only put the key if it does not already exist. If the index is non-zero, the key is only set if the index matches the ModifyIndex of that key.

pub fn acquire( self, value: &'a str, ) -> CreateOrUpdateKeyRequestBuilder<'a, SetAcquire<S>>
where S::Acquire: IsUnset,

Optional (Some / Option setters). Default: <&'a str as Default>::default().

Supply a session ID to use in a lock acquisition operation. This is useful as it allows leader election to be built on top of Consul. If the lock is not held and the session is valid, this increments the LockIndex and sets the Session value of the key in addition to updating the key contents. A key does not need to exist to be acquired. If the lock is already held by the given session, then the LockIndex is not incremented but the key contents are updated. This lets the current lock holder update the key contents without having to give up the lock and reacquire it. Note that an update that does not include the acquire parameter will proceed normally even if another session has locked the key.

pub fn maybe_acquire( self, value: Option<&'a str>, ) -> CreateOrUpdateKeyRequestBuilder<'a, SetAcquire<S>>
where S::Acquire: IsUnset,

Optional (Some / Option setters). Default: <&'a str as Default>::default().

Supply a session ID to use in a lock acquisition operation. This is useful as it allows leader election to be built on top of Consul. If the lock is not held and the session is valid, this increments the LockIndex and sets the Session value of the key in addition to updating the key contents. A key does not need to exist to be acquired. If the lock is already held by the given session, then the LockIndex is not incremented but the key contents are updated. This lets the current lock holder update the key contents without having to give up the lock and reacquire it. Note that an update that does not include the acquire parameter will proceed normally even if another session has locked the key.

pub fn release( self, value: &'a str, ) -> CreateOrUpdateKeyRequestBuilder<'a, SetRelease<S>>
where S::Release: IsUnset,

Optional (Some / Option setters). Default: <&'a str as Default>::default().

Supply a session ID to use in a release operation. This is useful when paired with ?acquire= as it allows clients to yield a lock. This will leave the LockIndex unmodified but will clear the associated Session of the key. The key must be held by this session to be unlocked.

pub fn maybe_release( self, value: Option<&'a str>, ) -> CreateOrUpdateKeyRequestBuilder<'a, SetRelease<S>>
where S::Release: IsUnset,

Optional (Some / Option setters). Default: <&'a str as Default>::default().

Supply a session ID to use in a release operation. This is useful when paired with ?acquire= as it allows clients to yield a lock. This will leave the LockIndex unmodified but will clear the associated Session of the key. The key must be held by this session to be unlocked.