DeleteKeyRequestBuilder

Struct DeleteKeyRequestBuilder 

pub struct DeleteKeyRequestBuilder<'a, S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<'a, S: State> DeleteKeyRequestBuilder<'a, S>

pub fn build(self) -> DeleteKeyRequest<'a>
where S: IsComplete,

Finish building and return the requested object

pub fn key(self, value: &'a str) -> DeleteKeyRequestBuilder<'a, SetKey<S>>
where S::Key: IsUnset,

Required.

Specifies the path of the key to delete.

pub fn datacenter( self, value: &'a str, ) -> DeleteKeyRequestBuilder<'a, SetDatacenter<S>>
where S::Datacenter: IsUnset,

Optional (Some / Option setters). Default: <&'a str as Default>::default().

Specifies the datacenter to query. This will default to the datacenter of the agent being queried.

pub fn maybe_datacenter( self, value: Option<&'a str>, ) -> DeleteKeyRequestBuilder<'a, SetDatacenter<S>>
where S::Datacenter: IsUnset,

Optional (Some / Option setters). Default: <&'a str as Default>::default().

Specifies the datacenter to query. This will default to the datacenter of the agent being queried.

pub fn recurse(self, value: bool) -> DeleteKeyRequestBuilder<'a, SetRecurse<S>>
where S::Recurse: IsUnset,

Optional (Some / Option setters). Default: false.

Specifies to delete all keys which have the specified prefix. Without this, only a key with an exact match will be deleted.

pub fn maybe_recurse( self, value: Option<bool>, ) -> DeleteKeyRequestBuilder<'a, SetRecurse<S>>
where S::Recurse: IsUnset,

Optional (Some / Option setters). Default: false.

Specifies to delete all keys which have the specified prefix. Without this, only a key with an exact match will be deleted.

pub fn check_and_set( self, value: u32, ) -> DeleteKeyRequestBuilder<'a, SetCheckAndSet<S>>
where S::CheckAndSet: IsUnset,

Optional (Some / Option setters). Default: 0.

Specifies to use a Check-And-Set operation. This is very useful as a building block for more complex synchronization primitives. The index must be greater than 0 for Consul to take any action: a 0 index will not delete the key. If the index is non-zero, the key is only deleted if the index matches the ModifyIndex of that key.

pub fn maybe_check_and_set( self, value: Option<u32>, ) -> DeleteKeyRequestBuilder<'a, SetCheckAndSet<S>>
where S::CheckAndSet: IsUnset,

Optional (Some / Option setters). Default: 0.

Specifies to use a Check-And-Set operation. This is very useful as a building block for more complex synchronization primitives. The index must be greater than 0 for Consul to take any action: a 0 index will not delete the key. If the index is non-zero, the key is only deleted if the index matches the ModifyIndex of that key.

pub fn namespace( self, value: &'a str, ) -> DeleteKeyRequestBuilder<'a, SetNamespace<S>>
where S::Namespace: IsUnset,

Optional (Some / Option setters). Default: <&'a str as Default>::default().

Specifies the namespace to query. If not provided, the namespace will be inferred from the request’s ACL token, or will default to the default namespace.

pub fn maybe_namespace( self, value: Option<&'a str>, ) -> DeleteKeyRequestBuilder<'a, SetNamespace<S>>
where S::Namespace: IsUnset,

Optional (Some / Option setters). Default: <&'a str as Default>::default().

Specifies the namespace to query. If not provided, the namespace will be inferred from the request’s ACL token, or will default to the default namespace.