GetNodesRequest

Struct GetNodesRequest 

pub struct GetNodesRequest<'a> {
    pub near: Option<&'a str>,
    pub filter: Option<&'a str>,
}
Request for the nodes providing a specified service registered in Consul. See https://developer.hashicorp.com/consul/api-docs/catalog#list-nodes for more information.

Fields

near: Option<&'a str>

Specifies a node name to sort the node list in ascending order based on the estimated round trip time from that node. Passing ?near=_agent will use the agent’s node for the sort. This is specified as part of the URL as a query parameter. Note that using near will ignore use_streaming_backend and always use blocking queries, because the data required to sort the results is not available to the streaming backend.

filter: Option<&'a str>

(string: “”) Specifies the expression used to filter the queries results prior to returning the data.

Implementations

Source

impl<'a> GetNodesRequest<'a>

pub fn builder() -> GetNodesRequestBuilder<'a>

Create an instance of GetNodesRequest using the builder syntax