GetNodesRequestBuilder

Struct GetNodesRequestBuilder 

pub struct GetNodesRequestBuilder<'a, S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<'a, S: State> GetNodesRequestBuilder<'a, S>

pub fn build(self) -> GetNodesRequest<'a>
where S: IsComplete,

Finish building and return the requested object

pub fn near(self, value: &'a str) -> GetNodesRequestBuilder<'a, SetNear<S>>
where S::Near: IsUnset,

Optional (Some / Option setters). Specifies a node name to sort the node list in ascending order based on the estimated round trip time from that node. Passing ?near=_agent will use the agent’s node for the sort. This is specified as part of the URL as a query parameter. Note that using near will ignore use_streaming_backend and always use blocking queries, because the data required to sort the results is not available to the streaming backend.

pub fn maybe_near( self, value: Option<&'a str>, ) -> GetNodesRequestBuilder<'a, SetNear<S>>
where S::Near: IsUnset,

Optional (Some / Option setters). Specifies a node name to sort the node list in ascending order based on the estimated round trip time from that node. Passing ?near=_agent will use the agent’s node for the sort. This is specified as part of the URL as a query parameter. Note that using near will ignore use_streaming_backend and always use blocking queries, because the data required to sort the results is not available to the streaming backend.

pub fn filter(self, value: &'a str) -> GetNodesRequestBuilder<'a, SetFilter<S>>
where S::Filter: IsUnset,

Optional (Some / Option setters). (string: “”) Specifies the expression used to filter the queries results prior to returning the data.

pub fn maybe_filter( self, value: Option<&'a str>, ) -> GetNodesRequestBuilder<'a, SetFilter<S>>
where S::Filter: IsUnset,

Optional (Some / Option setters). (string: “”) Specifies the expression used to filter the queries results prior to returning the data.