pub struct GetServiceNodesRequest<'a> {
pub service: &'a str,
pub near: Option<&'a str>,
pub passing: bool,
pub filter: Option<&'a str>,
}Expand description
Request to retrieve information about nodes int the Consul catalog.
Fields
service: &'a strSpecifies the service to list services for. This is provided as part of the URL.
near: Option<&'a str>Specifies a node name to sort the node list in ascending order based on the estimated round trip time from that node.
Passing ?near=_agent will use the agent’s node for the sort. This is specified as part of the URL as a query parameter.
Note that using near will ignore use_streaming_backend and always use blocking queries, because the data required to
sort the results is not available to the streaming backend.
passing: bool(bool: false) Specifies that the server should return only nodes with all checks in the passing state. This can be used to avoid additional filtering on the client side.
filter: Option<&'a str>(string: “”) Specifies the expression used to filter the queries results prior to returning the data.
Implementations
Sourceimpl<'a> GetServiceNodesRequest<'a>
impl<'a> GetServiceNodesRequest<'a>
Sourcepub fn builder() -> GetServiceNodesRequestBuilder<'a>
pub fn builder() -> GetServiceNodesRequestBuilder<'a>
Create an instance of GetServiceNodesRequest using the builder syntax