GetServiceNodesRequestBuilder

Struct GetServiceNodesRequestBuilder 

pub struct GetServiceNodesRequestBuilder<'a, S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<'a, S: State> GetServiceNodesRequestBuilder<'a, S>

pub fn build(self) -> GetServiceNodesRequest<'a>
where S: IsComplete,

Finish building and return the requested object

pub fn service( self, value: &'a str, ) -> GetServiceNodesRequestBuilder<'a, SetService<S>>
where S::Service: IsUnset,

Required.

Specifies the service to list services for. This is provided as part of the URL.

pub fn near( self, value: &'a str, ) -> GetServiceNodesRequestBuilder<'a, SetNear<S>>
where S::Near: IsUnset,

Optional (Some / Option setters). Specifies a node name to sort the node list in ascending order based on the estimated round trip time from that node. Passing ?near=_agent will use the agent’s node for the sort. This is specified as part of the URL as a query parameter. Note that using near will ignore use_streaming_backend and always use blocking queries, because the data required to sort the results is not available to the streaming backend.

pub fn maybe_near( self, value: Option<&'a str>, ) -> GetServiceNodesRequestBuilder<'a, SetNear<S>>
where S::Near: IsUnset,

Optional (Some / Option setters). Specifies a node name to sort the node list in ascending order based on the estimated round trip time from that node. Passing ?near=_agent will use the agent’s node for the sort. This is specified as part of the URL as a query parameter. Note that using near will ignore use_streaming_backend and always use blocking queries, because the data required to sort the results is not available to the streaming backend.

pub fn passing( self, value: bool, ) -> GetServiceNodesRequestBuilder<'a, SetPassing<S>>
where S::Passing: IsUnset,

Optional (Some / Option setters). Default: false.

(bool: false) Specifies that the server should return only nodes with all checks in the passing state. This can be used to avoid additional filtering on the client side.

pub fn maybe_passing( self, value: Option<bool>, ) -> GetServiceNodesRequestBuilder<'a, SetPassing<S>>
where S::Passing: IsUnset,

Optional (Some / Option setters). Default: false.

(bool: false) Specifies that the server should return only nodes with all checks in the passing state. This can be used to avoid additional filtering on the client side.

pub fn filter( self, value: &'a str, ) -> GetServiceNodesRequestBuilder<'a, SetFilter<S>>
where S::Filter: IsUnset,

Optional (Some / Option setters). (string: “”) Specifies the expression used to filter the queries results prior to returning the data.

pub fn maybe_filter( self, value: Option<&'a str>, ) -> GetServiceNodesRequestBuilder<'a, SetFilter<S>>
where S::Filter: IsUnset,

Optional (Some / Option setters). (string: “”) Specifies the expression used to filter the queries results prior to returning the data.