pub struct Node {
pub id: String,
pub node: String,
pub address: String,
pub datacenter: String,
}Expand description
The node information of an instance providing a Consul service.
Fields
id: StringThe ID of the service node.
node: StringThe name of the Consul node on which the service is registered
address: StringThe IP address of the Consul node on which the service is registered.
datacenter: StringThe datacenter where this node is running on.