ReadKeyRequestBuilder

Struct ReadKeyRequestBuilder 

pub struct ReadKeyRequestBuilder<'a, S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<'a, S: State> ReadKeyRequestBuilder<'a, S>

pub fn build(self) -> ReadKeyRequest<'a>
where S: IsComplete,

Finish building and return the requested object

pub fn key(self, value: &'a str) -> ReadKeyRequestBuilder<'a, SetKey<S>>
where S::Key: IsUnset,

Required.

Specifies the path of the key to read.

pub fn namespace( self, value: &'a str, ) -> ReadKeyRequestBuilder<'a, SetNamespace<S>>
where S::Namespace: IsUnset,

Optional (Some / Option setters). Default: <&'a str as Default>::default().

Specifies the namespace to query. If not provided, the namespace will be inferred from the request’s ACL token, or will default to the default namespace. For recursive lookups, the namespace may be specified as ‘*’ and then results will be returned for all namespaces. Added in Consul 1.7.0.

pub fn maybe_namespace( self, value: Option<&'a str>, ) -> ReadKeyRequestBuilder<'a, SetNamespace<S>>
where S::Namespace: IsUnset,

Optional (Some / Option setters). Default: <&'a str as Default>::default().

Specifies the namespace to query. If not provided, the namespace will be inferred from the request’s ACL token, or will default to the default namespace. For recursive lookups, the namespace may be specified as ‘*’ and then results will be returned for all namespaces. Added in Consul 1.7.0.

pub fn datacenter( self, value: &'a str, ) -> ReadKeyRequestBuilder<'a, SetDatacenter<S>>
where S::Datacenter: IsUnset,

Optional (Some / Option setters). Default: <&'a str as Default>::default().

Specifies the datacenter to query. This will default to the datacenter of the agent being queried.

pub fn maybe_datacenter( self, value: Option<&'a str>, ) -> ReadKeyRequestBuilder<'a, SetDatacenter<S>>
where S::Datacenter: IsUnset,

Optional (Some / Option setters). Default: <&'a str as Default>::default().

Specifies the datacenter to query. This will default to the datacenter of the agent being queried.

pub fn recurse(self, value: bool) -> ReadKeyRequestBuilder<'a, SetRecurse<S>>
where S::Recurse: IsUnset,

Optional (Some / Option setters). Default: false.

Specifies if the lookup should be recursive and key treated as a prefix instead of a literal match.

pub fn maybe_recurse( self, value: Option<bool>, ) -> ReadKeyRequestBuilder<'a, SetRecurse<S>>
where S::Recurse: IsUnset,

Optional (Some / Option setters). Default: false.

Specifies if the lookup should be recursive and key treated as a prefix instead of a literal match.

pub fn separator( self, value: &'a str, ) -> ReadKeyRequestBuilder<'a, SetSeparator<S>>
where S::Separator: IsUnset,

Optional (Some / Option setters). Default: <&'a str as Default>::default().

Specifies the string to use as a separator for recursive key lookups. This option is only used when paired with the keys parameter to limit the prefix of keys returned, only up to the given separator.

pub fn maybe_separator( self, value: Option<&'a str>, ) -> ReadKeyRequestBuilder<'a, SetSeparator<S>>
where S::Separator: IsUnset,

Optional (Some / Option setters). Default: <&'a str as Default>::default().

Specifies the string to use as a separator for recursive key lookups. This option is only used when paired with the keys parameter to limit the prefix of keys returned, only up to the given separator.

pub fn consistency( self, value: ConsistencyMode, ) -> ReadKeyRequestBuilder<'a, SetConsistency<S>>
where S::Consistency: IsUnset,

Optional (Some / Option setters). Default: <ConsistencyMode as Default>::default().

The consistency mode for reads. See also ConsistencyMode

pub fn maybe_consistency( self, value: Option<ConsistencyMode>, ) -> ReadKeyRequestBuilder<'a, SetConsistency<S>>
where S::Consistency: IsUnset,

Optional (Some / Option setters). Default: <ConsistencyMode as Default>::default().

The consistency mode for reads. See also ConsistencyMode

pub fn index(self, value: u64) -> ReadKeyRequestBuilder<'a, SetIndex<S>>
where S::Index: IsUnset,

Optional (Some / Option setters). Endpoints that support blocking queries return an HTTP header named X-Consul-Index. This is a unique identifier representing the current state of the requested resource. On subsequent requests for this resource, the client can set the index query string parameter to the value of X-Consul-Index, indicating that the client wishes to wait for any changes subsequent to that index.

pub fn maybe_index( self, value: Option<u64>, ) -> ReadKeyRequestBuilder<'a, SetIndex<S>>
where S::Index: IsUnset,

Optional (Some / Option setters). Endpoints that support blocking queries return an HTTP header named X-Consul-Index. This is a unique identifier representing the current state of the requested resource. On subsequent requests for this resource, the client can set the index query string parameter to the value of X-Consul-Index, indicating that the client wishes to wait for any changes subsequent to that index.

pub fn wait(self, value: Duration) -> ReadKeyRequestBuilder<'a, SetWait<S>>
where S::Wait: IsUnset,

Optional (Some / Option setters). Default: <Duration as Default>::default().

The time to wait for watching a lock in a blocking fashion.

pub fn maybe_wait( self, value: Option<Duration>, ) -> ReadKeyRequestBuilder<'a, SetWait<S>>
where S::Wait: IsUnset,

Optional (Some / Option setters). Default: <Duration as Default>::default().

The time to wait for watching a lock in a blocking fashion.