ReadKeyResponse

Struct ReadKeyResponse 

pub struct ReadKeyResponse {
    pub create_index: i64,
    pub modify_index: i64,
    pub lock_index: i64,
    pub key: String,
    pub flags: u64,
    pub value: Option<String>,
    pub session: Option<String>,
}
Represents a request to read a key from Consul Key Value store.

Fields

create_index: i64

CreateIndex is the internal index value that represents when the entry was created.

modify_index: i64

ModifyIndex is the last index that modified this key. It can be used to establish blocking queries by setting the ?index query parameter. You can even perform blocking queries against entire subtrees of the KV store: if ?recurse is provided, the returned X-Consul-Index corresponds to the latest ModifyIndex within the prefix, and a blocking query using that ?index will wait until any key within that prefix is updated.

lock_index: i64

LockIndex is the number of times this key has successfully been acquired in a lock. If the lock is held, the Session key provides the session that owns the lock.

key: String

Key is simply the full path of the entry.

flags: u64

Flags is an opaque unsigned integer that can be attached to each entry. Clients can choose to use this however makes sense for their application.

value: Option<String>

Value is a base64-encoded blob of data.

session: Option<String>

If a lock is held, the Session key provides the session that owns the lock.