pub struct RegisterEntityCheck {
pub Node: Option<String>,
pub CheckID: Option<String>,
pub Name: String,
pub Notes: Option<String>,
pub Status: Option<String>,
pub ServiceID: Option<String>,
pub Definition: HashMap<String, String>,
}Expand description
Information related to registering a check. See https://www.consul.io/docs/discovery/checks for more information.
Fields
Node: Option<String>The node to execute the check on.
CheckID: Option<String>Optional check id, defaults to the name of the check.
Name: StringThe name associated with the check
Notes: Option<String>Opaque field encapsulating human-readable text.
Status: Option<String>The status of the check. Must be one of ‘passing’, ‘warning’, or ‘critical’.
ServiceID: Option<String>ID of the service this check is for. If no ID of a service running on the node is provided, the check is treated as a node level check
Definition: HashMap<String, String>Details for a TCP or HTTP health check.
Implementations
Sourceimpl RegisterEntityCheck
impl RegisterEntityCheck
Sourcepub fn builder() -> RegisterEntityCheckBuilder
pub fn builder() -> RegisterEntityCheckBuilder
Create an instance of RegisterEntityCheck using the builder syntax