RegisterEntityCheckBuilder

Struct RegisterEntityCheckBuilder 

pub struct RegisterEntityCheckBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> RegisterEntityCheckBuilder<S>

pub fn build(self) -> RegisterEntityCheck
where S: IsComplete,

Finish building and return the requested object

pub fn Node(self, value: String) -> RegisterEntityCheckBuilder<SetNode<S>>
where S::Node: IsUnset,

Optional (Some / Option setters). The node to execute the check on.

pub fn maybe_Node( self, value: Option<String>, ) -> RegisterEntityCheckBuilder<SetNode<S>>
where S::Node: IsUnset,

Optional (Some / Option setters). The node to execute the check on.

pub fn CheckID(self, value: String) -> RegisterEntityCheckBuilder<SetCheckID<S>>
where S::CheckID: IsUnset,

Optional (Some / Option setters). Optional check id, defaults to the name of the check.

pub fn maybe_CheckID( self, value: Option<String>, ) -> RegisterEntityCheckBuilder<SetCheckID<S>>
where S::CheckID: IsUnset,

Optional (Some / Option setters). Optional check id, defaults to the name of the check.

pub fn Name(self, value: String) -> RegisterEntityCheckBuilder<SetName<S>>
where S::Name: IsUnset,

Required.

The name associated with the check

pub fn Notes(self, value: String) -> RegisterEntityCheckBuilder<SetNotes<S>>
where S::Notes: IsUnset,

Optional (Some / Option setters). Opaque field encapsulating human-readable text.

pub fn maybe_Notes( self, value: Option<String>, ) -> RegisterEntityCheckBuilder<SetNotes<S>>
where S::Notes: IsUnset,

Optional (Some / Option setters). Opaque field encapsulating human-readable text.

pub fn Status(self, value: String) -> RegisterEntityCheckBuilder<SetStatus<S>>
where S::Status: IsUnset,

Optional (Some / Option setters). The status of the check. Must be one of ‘passing’, ‘warning’, or ‘critical’.

pub fn maybe_Status( self, value: Option<String>, ) -> RegisterEntityCheckBuilder<SetStatus<S>>
where S::Status: IsUnset,

Optional (Some / Option setters). The status of the check. Must be one of ‘passing’, ‘warning’, or ‘critical’.

pub fn ServiceID( self, value: String, ) -> RegisterEntityCheckBuilder<SetServiceID<S>>
where S::ServiceID: IsUnset,

Optional (Some / Option setters). ID of the service this check is for. If no ID of a service running on the node is provided, the check is treated as a node level check

pub fn maybe_ServiceID( self, value: Option<String>, ) -> RegisterEntityCheckBuilder<SetServiceID<S>>
where S::ServiceID: IsUnset,

Optional (Some / Option setters). ID of the service this check is for. If no ID of a service running on the node is provided, the check is treated as a node level check

pub fn Definition( self, value: HashMap<String, String>, ) -> RegisterEntityCheckBuilder<SetDefinition<S>>
where S::Definition: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

Details for a TCP or HTTP health check.

pub fn maybe_Definition( self, value: Option<HashMap<String, String>>, ) -> RegisterEntityCheckBuilder<SetDefinition<S>>
where S::Definition: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

Details for a TCP or HTTP health check.