RegisterEntityPayload

Struct RegisterEntityPayload 

pub struct RegisterEntityPayload {
    pub ID: Option<String>,
    pub Node: String,
    pub Address: String,
    pub Datacenter: Option<String>,
    pub TaggedAddresses: HashMap<String, String>,
    pub NodeMeta: HashMap<String, String>,
    pub Service: Option<RegisterEntityService>,
    pub Checks: Vec<RegisterEntityCheck>,
    pub SkipNodeUpdate: Option<bool>,
}
Payload struct to register or update entries in consul’s catalog. See https://www.consul.io/api-docs/catalog#register-entity for more information.

Fields

ID: Option<String>

Optional UUID to assign to the node. This string is required to be 36-characters and UUID formatted.

Node: String

Node ID to register.

Address: String

The address to register.

Datacenter: Option<String>

The datacenter to register in, defaults to the agent’s datacenter.

TaggedAddresses: HashMap<String, String>

Tagged addressed to register with.

NodeMeta: HashMap<String, String>

KV metadata paris to register with.

Service: Option<RegisterEntityService>

Optional service to register.

Checks: Vec<RegisterEntityCheck>

Checks to register.

SkipNodeUpdate: Option<bool>

Whether to skip updating the nodes information in the registration.

Implementations

Source

impl RegisterEntityPayload

pub fn builder() -> RegisterEntityPayloadBuilder

Create an instance of RegisterEntityPayload using the builder syntax