RegisterEntityPayloadBuilder

Struct RegisterEntityPayloadBuilder 

pub struct RegisterEntityPayloadBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> RegisterEntityPayloadBuilder<S>

pub fn build(self) -> RegisterEntityPayload
where S: IsComplete,

Finish building and return the requested object

pub fn ID(self, value: String) -> RegisterEntityPayloadBuilder<SetID<S>>
where S::ID: IsUnset,

Optional (Some / Option setters). Optional UUID to assign to the node. This string is required to be 36-characters and UUID formatted.

pub fn maybe_ID( self, value: Option<String>, ) -> RegisterEntityPayloadBuilder<SetID<S>>
where S::ID: IsUnset,

Optional (Some / Option setters). Optional UUID to assign to the node. This string is required to be 36-characters and UUID formatted.

pub fn Node(self, value: String) -> RegisterEntityPayloadBuilder<SetNode<S>>
where S::Node: IsUnset,

Required.

Node ID to register.

pub fn Address( self, value: String, ) -> RegisterEntityPayloadBuilder<SetAddress<S>>
where S::Address: IsUnset,

Required.

The address to register.

pub fn Datacenter( self, value: String, ) -> RegisterEntityPayloadBuilder<SetDatacenter<S>>
where S::Datacenter: IsUnset,

Optional (Some / Option setters). The datacenter to register in, defaults to the agent’s datacenter.

pub fn maybe_Datacenter( self, value: Option<String>, ) -> RegisterEntityPayloadBuilder<SetDatacenter<S>>
where S::Datacenter: IsUnset,

Optional (Some / Option setters). The datacenter to register in, defaults to the agent’s datacenter.

pub fn TaggedAddresses( self, value: HashMap<String, String>, ) -> RegisterEntityPayloadBuilder<SetTaggedAddresses<S>>
where S::TaggedAddresses: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

Tagged addressed to register with.

pub fn maybe_TaggedAddresses( self, value: Option<HashMap<String, String>>, ) -> RegisterEntityPayloadBuilder<SetTaggedAddresses<S>>
where S::TaggedAddresses: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

Tagged addressed to register with.

pub fn NodeMeta( self, value: HashMap<String, String>, ) -> RegisterEntityPayloadBuilder<SetNodeMeta<S>>
where S::NodeMeta: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

KV metadata paris to register with.

pub fn maybe_NodeMeta( self, value: Option<HashMap<String, String>>, ) -> RegisterEntityPayloadBuilder<SetNodeMeta<S>>
where S::NodeMeta: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

KV metadata paris to register with.

pub fn Service( self, value: RegisterEntityService, ) -> RegisterEntityPayloadBuilder<SetService<S>>
where S::Service: IsUnset,

Optional (Some / Option setters). Optional service to register.

pub fn maybe_Service( self, value: Option<RegisterEntityService>, ) -> RegisterEntityPayloadBuilder<SetService<S>>
where S::Service: IsUnset,

Optional (Some / Option setters). Optional service to register.

pub fn Checks( self, value: Vec<RegisterEntityCheck>, ) -> RegisterEntityPayloadBuilder<SetChecks<S>>
where S::Checks: IsUnset,

Optional (Some / Option setters). Default: <Vec<RegisterEntityCheck> as Default>::default().

Checks to register.

pub fn maybe_Checks( self, value: Option<Vec<RegisterEntityCheck>>, ) -> RegisterEntityPayloadBuilder<SetChecks<S>>
where S::Checks: IsUnset,

Optional (Some / Option setters). Default: <Vec<RegisterEntityCheck> as Default>::default().

Checks to register.

pub fn SkipNodeUpdate( self, value: bool, ) -> RegisterEntityPayloadBuilder<SetSkipNodeUpdate<S>>
where S::SkipNodeUpdate: IsUnset,

Optional (Some / Option setters). Whether to skip updating the nodes information in the registration.

pub fn maybe_SkipNodeUpdate( self, value: Option<bool>, ) -> RegisterEntityPayloadBuilder<SetSkipNodeUpdate<S>>
where S::SkipNodeUpdate: IsUnset,

Optional (Some / Option setters). Whether to skip updating the nodes information in the registration.