ResponseMeta

Struct ResponseMeta 

pub struct ResponseMeta<T> {
    pub response: T,
    pub index: u64,
}
Encapsulates a consul query response and the returned metadata, if any.

Fields

response: T

Query response.

index: u64

The index returned from the consul query via the X-Consul-Index header.