pub struct DeleteKeyRequestBuilder<'a, S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<'a, S: State> DeleteKeyRequestBuilder<'a, S>
impl<'a, S: State> DeleteKeyRequestBuilder<'a, S>
Sourcepub fn build(self) -> DeleteKeyRequest<'a>where
S: IsComplete,
pub fn build(self) -> DeleteKeyRequest<'a>where
S: IsComplete,
Finish building and return the requested object
Sourcepub fn key(self, value: &'a str) -> DeleteKeyRequestBuilder<'a, SetKey<S>>where
S::Key: IsUnset,
pub fn key(self, value: &'a str) -> DeleteKeyRequestBuilder<'a, SetKey<S>>where
S::Key: IsUnset,
Required.
Specifies the path of the key to delete.
Sourcepub fn datacenter(
self,
value: &'a str,
) -> DeleteKeyRequestBuilder<'a, SetDatacenter<S>>where
S::Datacenter: IsUnset,
pub fn datacenter(
self,
value: &'a str,
) -> DeleteKeyRequestBuilder<'a, SetDatacenter<S>>where
S::Datacenter: IsUnset,
Sourcepub fn maybe_datacenter(
self,
value: Option<&'a str>,
) -> DeleteKeyRequestBuilder<'a, SetDatacenter<S>>where
S::Datacenter: IsUnset,
pub fn maybe_datacenter(
self,
value: Option<&'a str>,
) -> DeleteKeyRequestBuilder<'a, SetDatacenter<S>>where
S::Datacenter: IsUnset,
Sourcepub fn recurse(self, value: bool) -> DeleteKeyRequestBuilder<'a, SetRecurse<S>>where
S::Recurse: IsUnset,
pub fn recurse(self, value: bool) -> DeleteKeyRequestBuilder<'a, SetRecurse<S>>where
S::Recurse: IsUnset,
Sourcepub fn maybe_recurse(
self,
value: Option<bool>,
) -> DeleteKeyRequestBuilder<'a, SetRecurse<S>>where
S::Recurse: IsUnset,
pub fn maybe_recurse(
self,
value: Option<bool>,
) -> DeleteKeyRequestBuilder<'a, SetRecurse<S>>where
S::Recurse: IsUnset,
Sourcepub fn check_and_set(
self,
value: u32,
) -> DeleteKeyRequestBuilder<'a, SetCheckAndSet<S>>where
S::CheckAndSet: IsUnset,
pub fn check_and_set(
self,
value: u32,
) -> DeleteKeyRequestBuilder<'a, SetCheckAndSet<S>>where
S::CheckAndSet: IsUnset,
Optional (Some / Option setters).
Default: 0.
Specifies to use a Check-And-Set operation. This is very useful as a building block for more complex synchronization primitives. The index must be greater than 0 for Consul to take any action: a 0 index will not delete the key. If the index is non-zero, the key is only deleted if the index matches the ModifyIndex of that key.
Sourcepub fn maybe_check_and_set(
self,
value: Option<u32>,
) -> DeleteKeyRequestBuilder<'a, SetCheckAndSet<S>>where
S::CheckAndSet: IsUnset,
pub fn maybe_check_and_set(
self,
value: Option<u32>,
) -> DeleteKeyRequestBuilder<'a, SetCheckAndSet<S>>where
S::CheckAndSet: IsUnset,
Optional (Some / Option setters).
Default: 0.
Specifies to use a Check-And-Set operation. This is very useful as a building block for more complex synchronization primitives. The index must be greater than 0 for Consul to take any action: a 0 index will not delete the key. If the index is non-zero, the key is only deleted if the index matches the ModifyIndex of that key.