pub struct GetServiceNodesRequestBuilder<'a, S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<'a, S: State> GetServiceNodesRequestBuilder<'a, S>
impl<'a, S: State> GetServiceNodesRequestBuilder<'a, S>
Sourcepub fn build(self) -> GetServiceNodesRequest<'a>where
S: IsComplete,
pub fn build(self) -> GetServiceNodesRequest<'a>where
S: IsComplete,
Finish building and return the requested object
Sourcepub fn service(
self,
value: &'a str,
) -> GetServiceNodesRequestBuilder<'a, SetService<S>>where
S::Service: IsUnset,
pub fn service(
self,
value: &'a str,
) -> GetServiceNodesRequestBuilder<'a, SetService<S>>where
S::Service: IsUnset,
Required.
Specifies the service to list services for. This is provided as part of the URL.
Sourcepub fn near(
self,
value: &'a str,
) -> GetServiceNodesRequestBuilder<'a, SetNear<S>>where
S::Near: IsUnset,
pub fn near(
self,
value: &'a str,
) -> GetServiceNodesRequestBuilder<'a, SetNear<S>>where
S::Near: IsUnset,
Optional (Some / Option setters).
Specifies a node name to sort the node list in ascending order based on the estimated round trip time from that node.
Passing ?near=_agent will use the agent’s node for the sort. This is specified as part of the URL as a query parameter.
Note that using near will ignore use_streaming_backend and always use blocking queries, because the data required to
sort the results is not available to the streaming backend.
Sourcepub fn maybe_near(
self,
value: Option<&'a str>,
) -> GetServiceNodesRequestBuilder<'a, SetNear<S>>where
S::Near: IsUnset,
pub fn maybe_near(
self,
value: Option<&'a str>,
) -> GetServiceNodesRequestBuilder<'a, SetNear<S>>where
S::Near: IsUnset,
Optional (Some / Option setters).
Specifies a node name to sort the node list in ascending order based on the estimated round trip time from that node.
Passing ?near=_agent will use the agent’s node for the sort. This is specified as part of the URL as a query parameter.
Note that using near will ignore use_streaming_backend and always use blocking queries, because the data required to
sort the results is not available to the streaming backend.