pub struct ResponseMeta<T> {
pub response: T,
pub index: u64,
}Expand description
Encapsulates a consul query response and the returned metadata, if any.
Fields
response: TQuery response.
index: u64The index returned from the consul query via the X-Consul-Index header.